function k = kurt(X,dim)
%KURT Computes sample kurtosis
%
% CALL:  k = kurt(X,dim);
%
%        k = sample kurtosis (fourth central moment divided by squared second)
%        X = data vector or matrix
%      dim = dimension to sum across. (default 1'st non-singleton 
%                                              dimension of X)
%
% Example:  
%   R = rndgumb(2,2,100,2);
%   kurt(R);
%
% See also   mean, varskew, skew

%
%     This program is free software; you can redistribute it and/or modify
%     it under the terms of the GNU Lesser General Public License as published by
%     the Free Software Foundation; either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU Lesser General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.


% Tested on: Matlab 5.3
% History:
% revised pab 24.10.2000
% - made it more general: accepts any size of X
% - added dim, nargchk
% added ms 16.06.2000

%error(nargchk(1,2,nargin))
narginchk(1,2)
sz = size(X);
if nargin<2||isempty(dim)
  % Use 1'st non-singleton dimension or dimension 1
  dim = find(sz~=1, 1 ); 
  if isempty(dim), dim = 1; end
end
rsz = ones(size(sz)); rsz(dim)=sz(dim);
mu  = mean(X,dim);
if isscalar(mu)
    Xmu2 = (X-mu).^2;
else
    Xmu2 = (X-repmat(mu,rsz)).^2;
end
k   = mean(Xmu2.^2,dim)./mean(Xmu2,dim).^2;
end






